@@ -5,6 +5,7 @@
 # Please see the file LICENSE.txt for details.
 
 import os
+import numpy as np
 
 from ginga.gtk3w import GtkHelp
 from ginga import Mixins, Bindings
@@ -55,7 +56,7 @@ class ImageViewGtk(ImageView):
         return self.imgwin
 
     def get_plain_image_as_pixbuf(self):
-        arr = self.getwin_array(order='RGB')
+        arr = self.getwin_array(order='RGB', dtype=np.uint8)
         pixbuf = GtkHelp.pixbuf_new_from_array(arr,
                                                GdkPixbuf.Colorspace.RGB,
                                                8)
@@ -193,6 +194,9 @@ class ImageViewGtk(ImageView):
         if delay is not None:
             self.msgtask.start(delay)
 
+    def take_focus(self):
+        self.imgwin.grab_focus()
+
 
 class ImageViewEvent(ImageViewGtk):
 
@@ -236,9 +240,6 @@ class ImageViewEvent(ImageViewGtk):
                              Gdk.DragAction.COPY)
         imgwin.drag_dest_add_text_targets()
 
-        # Does widget accept focus when mouse enters window
-        self.enter_focus = self.t_.get('enter_focus', True)
-
         # @$%&^(_)*&^ gnome!!
         self._keytbl = {
             'shift_l': 'shift_l',
@@ -333,9 +334,6 @@ class ImageViewEvent(ImageViewGtk):
     def get_keyTable(self):
         return self._keytbl
 
-    def set_enter_focus(self, tf):
-        self.enter_focus = tf
-
     def map_event(self, widget, event):
         super(ImageViewZoom, self).configure_event(widget, event)
         return self.make_callback('map')
@@ -344,7 +342,8 @@ class ImageViewEvent(ImageViewGtk):
         return self.make_callback('focus', hasFocus)
 
     def enter_notify_event(self, widget, event):
-        if self.enter_focus:
+        enter_focus = self.t_.get('enter_focus', False)
+        if enter_focus:
             widget.grab_focus()
         return self.make_callback('enter')
 
@@ -570,6 +569,7 @@ class ScrolledView(Gtk.Table):
         self._adjusting = False
         self._scrolling = False
         self.pad = 20
+        self.sb_thickness = 20
         self.rng_x = 100.0
         self.rng_y = 100.0
 
@@ -584,16 +584,12 @@ class ScrolledView(Gtk.Table):
 
         self.hsb = Gtk.HScrollbar()
         self.hsb.set_round_digits(4)
+        self.hsb.set_size_request(-1, self.sb_thickness)
         self.hsb.connect('value-changed', self._scroll_contents)
-        self.attach(self.hsb, 0, 1, 1, 2,
-                    xoptions=Gtk.AttachOptions.FILL, yoptions=0,
-                    xpadding=0, ypadding=0)
         self.vsb = Gtk.VScrollbar()
         self.vsb.set_round_digits(4)
+        self.vsb.set_size_request(self.sb_thickness, -1)
         self.vsb.connect('value-changed', self._scroll_contents)
-        self.attach(self.vsb, 1, 2, 0, 1,
-                    xoptions=0, yoptions=Gtk.AttachOptions.FILL,
-                    xpadding=0, ypadding=0)
 
         self.viewer.add_callback('redraw', self._calc_scrollbars)
         self.viewer.add_callback('limits-set',
@@ -665,25 +661,27 @@ class ScrolledView(Gtk.Table):
         return True
 
     def scroll_bars(self, horizontal='on', vertical='on'):
-        if horizontal == 'on':
-            pass
+        if horizontal in ('on', 'auto'):
+            self.attach(self.hsb, 0, 1, 1, 2,
+                        xoptions=Gtk.AttachOptions.FILL, yoptions=0,
+                        xpadding=0, ypadding=0)
+            self.hsb.show()
         elif horizontal == 'off':
-            pass
-        elif horizontal == 'auto':
-            pass
+            self.remove(self.hsb)
         else:
             raise ValueError("Bad scroll bar option: '%s'; should be one of ('on', 'off' or 'auto')" % (horizontal))
 
-        if vertical == 'on':
-            pass
+        if vertical in ('on', 'auto'):
+            self.attach(self.vsb, 1, 2, 0, 1,
+                        xoptions=0, yoptions=Gtk.AttachOptions.FILL,
+                        xpadding=0, ypadding=0)
+            self.vsb.show()
         elif vertical == 'off':
-            pass
-        elif vertical == 'auto':
-            pass
+            self.remove(self.vsb)
         else:
             raise ValueError("Bad scroll bar option: '%s'; should be one of ('on', 'off' or 'auto')" % (vertical))
 
-        self.viewer.logger.warning("scroll_bar(): settings for gtk3 currently ignored!")
+        #self.viewer.logger.warning("scroll_bar(): settings for gtk currently ignored!")
 
 
 #END
