@@ -5,6 +5,7 @@
 # Please see the file LICENSE.txt for details.
 
 import os
+import numpy as np
 
 import gtk
 import cairo
@@ -52,7 +53,7 @@ class ImageViewGtk(ImageViewCairo.ImageViewCairo):
         return self.imgwin
 
     def get_plain_image_as_pixbuf(self):
-        arr = self.getwin_array(order='RGB')
+        arr = self.getwin_array(order='RGB', dtype=np.uint8)
 
         try:
             pixbuf = GtkHelp.pixbuf_new_from_array(
@@ -218,6 +219,9 @@ class ImageViewGtk(ImageViewCairo.ImageViewCairo):
         if delay is not None:
             self.msgtask.start(delay)
 
+    def take_focus(self):
+        self.imgwin.grab_focus()
+
 
 class ImageViewEvent(ImageViewGtk):
 
@@ -266,9 +270,6 @@ class ImageViewEvent(ImageViewGtk):
         imgwin.drag_dest_set(gtk.DEST_DEFAULT_ALL, toImage,
                              gtk.gdk.ACTION_COPY)
 
-        # Does widget accept focus when mouse enters window
-        self.enter_focus = self.t_.get('enter_focus', True)
-
         # @$%&^(_)*&^ gnome!!
         self._keytbl = {
             'shift_l': 'shift_l',
@@ -363,9 +364,6 @@ class ImageViewEvent(ImageViewGtk):
     def get_keyTable(self):
         return self._keytbl
 
-    def set_enter_focus(self, tf):
-        self.enter_focus = tf
-
     def map_event(self, widget, event):
         super(ImageViewZoom, self).configure_event(widget, event)
         return self.make_callback('map')
@@ -374,7 +372,8 @@ class ImageViewEvent(ImageViewGtk):
         return self.make_callback('focus', hasFocus)
 
     def enter_notify_event(self, widget, event):
-        if self.enter_focus:
+        enter_focus = self.t_.get('enter_focus', False)
+        if enter_focus:
             widget.grab_focus()
         return self.make_callback('enter')
 
@@ -566,125 +565,6 @@ class CanvasView(ImageViewZoom):
         self.objects[0] = self.private_canvas
 
 
-class ScrolledView1(gtk.ScrolledWindow):
-    """A class that can take a viewer as a parameter and add scroll bars
-    that respond to the pan/zoom levels.
-    """
-
-    def __init__(self, viewer, parent=None):
-        self.viewer = viewer
-        super(ScrolledView, self).__init__()
-
-        # the window jiggles annoyingly as the scrollbar is alternately
-        # shown and hidden if we use the default "automatic" policy, so
-        # default to always showing them (user can change this after
-        # calling the constructor, if desired)
-        self.scroll_bars(horizontal='on', vertical='on')
-
-        self.set_border_width(0)
-
-        self._adjusting = False
-        self._scrolling = False
-        self.pad = 20
-        self.upper_h = 100.0
-        self.upper_v = 100.0
-
-        # reparent the viewer widget
-        self.v_w = viewer.get_widget()
-        self.add(self.v_w)
-
-        hsb = self.get_hadjustment()
-        hsb.connect('value-changed', self._scroll_contents)
-        vsb = self.get_vadjustment()
-        vsb.connect('value-changed', self._scroll_contents)
-
-        self.viewer.add_callback('redraw', self._calc_scrollbars)
-        self.viewer.add_callback('limits-set',
-                                 lambda v, l: self._calc_scrollbars(v))
-
-    def get_widget(self):
-        return self
-
-    def _calc_scrollbars(self, viewer):
-        """Calculate and set the scrollbar handles from the pan and
-        zoom positions.
-        """
-        if self._scrolling:
-            return
-
-        # flag that suppresses a cyclical callback
-        self._adjusting = True
-        try:
-            bd = self.viewer.get_bindings()
-            res = bd.calc_pan_pct(self.viewer, pad=self.pad)
-            if res is None:
-                return
-
-            hsb = self.get_hadjustment()
-            vsb = self.get_vadjustment()
-
-            page_h, page_v = (int(round(res.thm_pct_x * 100)),
-                              int(round(res.thm_pct_y * 100)))
-
-            self.upper_h, self.upper_v = 100 + page_h, 100 + page_v
-
-            ## val_h, val_v = (int(round(res.pan_pct_x * 100)),
-            ##                 int(round((1.0 - res.pan_pct_y) * 100)))
-            val_h, val_v = (int(round(res.pan_pct_x * 100.0)),
-                            int(round((1.0 - res.pan_pct_y) * 100.0)))
-
-            hsb.configure(val_h, 0, self.upper_h, 1, page_h, page_h)
-            vsb.configure(val_v, 0, self.upper_v, 1, page_v, page_v)
-
-        finally:
-            self._adjusting = False
-
-    def _scroll_contents(self, adj):
-        """Called when the scroll bars are adjusted by the user.
-        """
-        if self._adjusting:
-            return
-
-        self._scrolling = True
-        try:
-            hsb = self.get_hadjustment()
-            vsb = self.get_vadjustment()
-
-            pos_x = hsb.get_value()
-            pos_y = vsb.get_value()
-
-            pct_x = pos_x / 100.0
-            # invert Y pct because of orientation of scrollbar
-            pct_y = 1.0 - (pos_y / 100.0)
-
-            bd = self.viewer.get_bindings()
-            bd.pan_by_pct(self.viewer, pct_x, pct_y, pad=self.pad)
-
-        finally:
-            self._scrolling = False
-
-    def scroll_bars(self, horizontal='on', vertical='on'):
-        if horizontal == 'on':
-            hpolicy = gtk.POLICY_ALWAYS
-        elif horizontal == 'off':
-            hpolicy = gtk.POLICY_NEVER
-        elif horizontal == 'auto':
-            hpolicy = gtk.POLICY_AUTOMATIC
-        else:
-            raise ValueError("Bad scroll bar option: '%s'; should be one of ('on', 'off' or 'auto')" % (horizontal))
-
-        if vertical == 'on':
-            vpolicy = gtk.POLICY_ALWAYS
-        elif vertical == 'off':
-            vpolicy = gtk.POLICY_NEVER
-        elif vertical == 'auto':
-            vpolicy = gtk.POLICY_AUTOMATIC
-        else:
-            raise ValueError("Bad scroll bar option: '%s'; should be one of ('on', 'off' or 'auto')" % (vertical))
-
-        self.set_policy(hpolicy, vpolicy)
-
-
 class ScrolledView(gtk.Table):
     """A class that can take a viewer as a parameter and add scroll bars
     that respond to the pan/zoom levels.
@@ -701,6 +581,7 @@ class ScrolledView(gtk.Table):
         self._adjusting = False
         self._scrolling = False
         self.pad = 20
+        self.sb_thickness = 20
         self.rng_x = 100.0
         self.rng_y = 100.0
 
@@ -715,14 +596,12 @@ class ScrolledView(gtk.Table):
 
         self.hsb = gtk.HScrollbar()
         self.hsb.set_round_digits(4)
+        self.hsb.set_size_request(-1, self.sb_thickness)
         self.hsb.connect('value-changed', self._scroll_contents)
-        self.attach(self.hsb, 0, 1, 1, 2,
-                    xoptions=gtk.FILL, yoptions=0, xpadding=0, ypadding=0)
         self.vsb = gtk.VScrollbar()
         self.vsb.set_round_digits(4)
+        self.vsb.set_size_request(self.sb_thickness, -1)
         self.vsb.connect('value-changed', self._scroll_contents)
-        self.attach(self.vsb, 1, 2, 0, 1,
-                    xoptions=0, yoptions=gtk.FILL, xpadding=0, ypadding=0)
 
         self.viewer.add_callback('redraw', self._calc_scrollbars)
         self.viewer.add_callback('limits-set',
@@ -793,24 +672,24 @@ class ScrolledView(gtk.Table):
         return True
 
     def scroll_bars(self, horizontal='on', vertical='on'):
-        if horizontal == 'on':
-            pass
+        if horizontal in ('on', 'auto'):
+            self.attach(self.hsb, 0, 1, 1, 2,
+                        xoptions=gtk.FILL, yoptions=0, xpadding=0, ypadding=0)
+            self.hsb.show()
         elif horizontal == 'off':
-            pass
-        elif horizontal == 'auto':
-            pass
+            self.remove(self.hsb)
         else:
             raise ValueError("Bad scroll bar option: '%s'; should be one of ('on', 'off' or 'auto')" % (horizontal))
 
-        if vertical == 'on':
-            pass
+        if vertical in ('on', 'auto'):
+            self.attach(self.vsb, 1, 2, 0, 1,
+                        xoptions=0, yoptions=gtk.FILL, xpadding=0, ypadding=0)
+            self.vsb.show()
         elif vertical == 'off':
-            pass
-        elif vertical == 'auto':
-            pass
+            self.remove(self.vsb)
         else:
             raise ValueError("Bad scroll bar option: '%s'; should be one of ('on', 'off' or 'auto')" % (vertical))
 
-        self.viewer.logger.warning("scroll_bar(): settings for gtk currently ignored!")
+        #self.viewer.logger.warning("scroll_bar(): settings for gtk currently ignored!")
 
 #END
