@@ -10,6 +10,7 @@ from io import BytesIO
 # Matplotlib imports
 import matplotlib
 #from matplotlib.path import Path
+import numpy as np
 
 from ginga import ImageView
 from ginga import Mixins, Bindings
@@ -166,7 +167,7 @@ class ImageViewMpl(ImageView.ImageViewBase):
 
         # Grab the RGB array for the current image and place it in the
         # matplotlib figure axis
-        data = self.getwin_array(order=self.rgb_order)
+        data = self.getwin_array(order=self.rgb_order, dtype=np.uint8)
 
         dst_x = dst_y = 0
 
@@ -201,7 +202,7 @@ class ImageViewMpl(ImageView.ImageViewBase):
 
         # Grab the RGB array for the current image and place it in the
         # matplotlib figure axis
-        arr = self.getwin_array(order=self.rgb_order)
+        arr = self.getwin_array(order=self.rgb_order, dtype=np.uint8)
 
         # Get the data extents
         x0, y0 = 0, 0
@@ -336,9 +337,6 @@ class ImageViewEvent(ImageViewMpl):
         ImageViewMpl.__init__(self, logger=logger, rgbmap=rgbmap,
                               settings=settings)
 
-        # Does widget accept focus when mouse enters window
-        self.enter_focus = self.t_.get('enter_focus', True)
-
         # @$%&^(_)*&^ gnome!!
         self._keytbl = {
             'shift': 'shift_l',
@@ -432,20 +430,19 @@ class ImageViewEvent(ImageViewMpl):
     def get_keyTable(self):
         return self._keytbl
 
-    def set_enter_focus(self, tf):
-        self.enter_focus = tf
-
     def focus_event(self, event, hasFocus):
         return self.make_callback('focus', hasFocus)
 
     def enter_notify_event(self, event):
-        if self.enter_focus:
+        enter_focus = self.t_.get('enter_focus', False)
+        if enter_focus:
             self.focus_event(event, True)
         return self.make_callback('enter')
 
     def leave_notify_event(self, event):
         self.logger.debug("leaving widget...")
-        if self.enter_focus:
+        enter_focus = self.t_.get('enter_focus', False)
+        if enter_focus:
             self.focus_event(event, False)
         return self.make_callback('leave')
 
