@@ -9,6 +9,8 @@ from __future__ import absolute_import
 import os
 from io import BytesIO
 
+import numpy as np
+
 import ginga.util.six as six
 from ginga.util.six.moves import map
 from ginga import ImageView, Mixins, Bindings
@@ -125,8 +127,10 @@ class ImageViewQt(ImageView.ImageViewBase):
             raise ImageViewQtError("Undefined render type: '%s'" % (render))
         self.imgwin.viewer = self
         self.pixmap = None
-        # Qt expects 32bit BGRA data for color images
+        # NOTE: we could use the following, but it is only for Qt5.x
+        # Asking for image in BGRA puts numpy array in ARGB format
         self.rgb_order = 'BGRA'
+        self.qimg_fmt = QImage.Format_ARGB32
 
         self.renderer = CanvasRenderer(self)
 
@@ -175,7 +179,8 @@ class ImageViewQt(ImageView.ImageViewBase):
         self.logger.debug("drawing to pixmap")
 
         # Prepare array for rendering
-        arr = rgbobj.get_array(self.rgb_order)
+        # TODO: what are options for high bit depth under Qt?
+        arr = rgbobj.get_array(self.rgb_order, dtype=np.uint8)
         (height, width) = arr.shape[:2]
 
         return self._render_offscreen(self.pixmap, arr, dst_x, dst_y,
@@ -292,13 +297,12 @@ class ImageViewQt(ImageView.ImageViewBase):
     def make_timer(self):
         return Timer()
 
-    def _get_qimage(self, bgra):
-        h, w, channels = bgra.shape
+    def _get_qimage(self, rgb_data):
+        ht, wd, channels = rgb_data.shape
 
-        fmt = QImage.Format_ARGB32
-        result = QImage(bgra.data, w, h, fmt)
+        result = QImage(rgb_data.data, wd, ht, self.qimg_fmt)
         # Need to hang on to a reference to the array
-        result.ndarray = bgra
+        result.ndarray = rgb_data
         return result
 
     def _get_color(self, r, g, b):
@@ -312,6 +316,9 @@ class ImageViewQt(ImageView.ImageViewBase):
         if delay is not None:
             self.msgtimer.start(delay)
 
+    def take_focus(self):
+        self.imgwin.setFocus()
+
 
 class RenderMixin(object):
 
@@ -408,9 +415,6 @@ class QtEventMixin(object):
         #imgwin.grabGesture(QtCore.Qt.TapGesture)
         #imgwin.grabGesture(QtCore.Qt.TapAndHoldGesture)
 
-        # Does widget accept focus when mouse enters window
-        self.enter_focus = self.t_.get('enter_focus', True)
-
         # Define cursors
         for curname, filename in (('pan', 'openHandCursor.png'),
                                   ('pick', 'thinCrossCursor.png')):
@@ -441,9 +445,6 @@ class QtEventMixin(object):
                      ):
             self.enable_callback(name)
 
-    def set_enter_focus(self, tf):
-        self.enter_focus = tf
-
     def transkey(self, keycode, keyname):
         self.logger.debug("keycode=%d keyname='%s'" % (
             keycode, keyname))
@@ -508,7 +509,8 @@ class QtEventMixin(object):
         return self.make_callback('focus', hasFocus)
 
     def enter_notify_event(self, widget, event):
-        if self.enter_focus:
+        enter_focus = self.t_.get('enter_focus', False)
+        if enter_focus:
             widget.setFocus()
         return self.make_callback('enter')
 
