@@ -128,11 +128,6 @@ class GingaShell(GwMain.GwMain, Widgets.Application):
 
         # Create general preferences
         self.settings = self.prefs.create_category('general')
-        self.settings.load(onError='silent')
-        # Load bindings preferences
-        bindprefs = self.prefs.create_category('bindings')
-        bindprefs.load(onError='silent')
-
         self.settings.add_defaults(fixedFont=None,
                                    serifFont=None,
                                    sansFont=None,
@@ -145,10 +140,12 @@ class GingaShell(GwMain.GwMain, Widgets.Application):
                                    # inherit from primary header
                                    inherit_primary_header=False,
                                    cursor_interval=0.050,
-                                   save_layout=False)
-
-        # Should channel change as mouse moves between windows
-        self.channel_follows_focus = self.settings['channel_follows_focus']
+                                   save_layout=False,
+                                   channel_prefix="Image")
+        self.settings.load(onError='silent')
+        # Load bindings preferences
+        bindprefs = self.prefs.create_category('bindings')
+        bindprefs.load(onError='silent')
 
         self.plugins = []
         self._plugin_sort_method = self.get_plugin_menuname
@@ -877,7 +874,7 @@ class GingaShell(GwMain.GwMain, Widgets.Application):
         self.next_channel_ws(ws)
 
     def add_channel_auto_ws(self, ws):
-        chpfx = "Image"
+        chpfx = self.settings.get('channel_prefix', "Image")
         chpfx = ws.extdata.get('chpfx', chpfx)
 
         chname = self.make_channel_name(chpfx)
@@ -1210,7 +1207,7 @@ class GingaShell(GwMain.GwMain, Widgets.Application):
                                           self.settings.get('numImages', 1))
             settings.set_defaults(switchnew=True, numImages=num_images,
                                   raisenew=True, genthumb=True,
-                                  enter_focus=True, focus_indicator=False,
+                                  focus_indicator=False,
                                   preload_images=False, sort_order='loadtime')
 
             self.logger.debug("Adding channel '%s'" % (chname))
@@ -1356,7 +1353,7 @@ class GingaShell(GwMain.GwMain, Widgets.Application):
         self.remove_image_by_name(channel.name, imname, impath=impath)
 
     def follow_focus(self, tf):
-        self.channel_follows_focus = tf
+        self.settings['channel_follows_focus'] = tf
 
     def show_status(self, text):
         """Write a message to the status bar.
@@ -1703,10 +1700,16 @@ class GingaShell(GwMain.GwMain, Widgets.Application):
         canvas.enable_draw(False)
         fi.set_canvas(canvas)
 
-        fi.set_enter_focus(settings.get('enter_focus', True))
+        # check general settings for default value of enter_focus
+        enter_focus = settings.get('enter_focus', None)
+        if enter_focus is None:
+            enter_focus = self.settings.get('enter_focus', True)
+        fi.set_enter_focus(enter_focus)
         # check general settings for default value of focus indicator
-        focus_ind = self.settings.get('focus_indicator', False)
-        fi.show_focus_indicator(self.settings.get('focus_indicator', focus_ind))
+        focus_ind = settings.get('show_focus_indicator', None)
+        if focus_ind is None:
+            focus_ind = self.settings.get('show_focus_indicator', False)
+        fi.show_focus_indicator(focus_ind)
         fi.enable_auto_orient(True)
 
         fi.add_callback('cursor-changed', self.motion_cb)
@@ -1738,15 +1741,16 @@ class GingaShell(GwMain.GwMain, Widgets.Application):
         # build image viewer & widget
         fi = self.build_viewpane(settings, size=size)
 
-        # add scrollbar interface around this viewer
-        scr_onoff = self.settings.get('scrollbars', 'off')
-        scr = settings.get('scrollbars', scr_onoff)
-        if scr != 'off':
-            si = Viewers.ScrolledView(fi)
-            si.scroll_bars(horizontal=scr, vertical=scr)
-            iw = Widgets.wrap(si)
-        else:
-            iw = Viewers.GingaViewerWidget(viewer=fi)
+        # add scrollbar support
+        scr_val = settings.setdefault('scrollbars', None)
+        scr_set = settings.get_setting('scrollbars')
+        if scr_val is None:
+            # general settings as backup value if not overridden in channel
+            scr_val = self.settings.get('scrollbars', 'off')
+        si = Viewers.ScrolledView(fi)
+        si.scroll_bars(horizontal=scr_val, vertical=scr_val)
+        scr_set.add_callback('set', self._toggle_scrollbars, si)
+        iw = Widgets.wrap(si)
 
         stk_w = Widgets.StackWidget()
         stk_w.add_widget(iw, title='image')
@@ -1765,8 +1769,11 @@ class GingaShell(GwMain.GwMain, Widgets.Application):
                            workspace=workspace)
         return bnch
 
+    def _toggle_scrollbars(self, setting, value, widget):
+        widget.scroll_bars(horizontal=value, vertical=value)
+
     def gui_add_channel(self, chname=None):
-        chpfx = "Image"
+        chpfx = self.settings.get('channel_prefix', "Image")
         ws = self.get_current_workspace()
         if ws is not None:
             chpfx = ws.extdata.get('chpfx', chpfx)
@@ -1804,8 +1811,7 @@ class GingaShell(GwMain.GwMain, Widgets.Application):
         self.ds.show_dialog(dialog)
 
     def gui_add_channels(self):
-
-        chpfx = "Image"
+        chpfx = self.settings.get('channel_prefix', "Image")
         ws = self.get_current_workspace()
         if ws is not None:
             chpfx = ws.extdata.get('chpfx', chpfx)
@@ -1892,8 +1898,7 @@ class GingaShell(GwMain.GwMain, Widgets.Application):
             self.gui_delete_window(chname)
 
     def gui_add_ws(self):
-
-        chpfx = "Image"
+        chpfx = self.settings.get('channel_prefix', "Image")
         ws = self.get_current_workspace()
         if ws is not None:
             chpfx = ws.extdata.get('chpfx', chpfx)
@@ -2472,17 +2477,23 @@ class GingaShell(GwMain.GwMain, Widgets.Application):
 
     def force_focus_cb(self, viewer, event, data_x, data_y):
         chname = self.get_channel_name(viewer)
-        self.change_channel(chname, raisew=True)
+        channel = self.get_channel(chname)
+        v = channel.viewer
+        if hasattr(v, 'take_focus'):
+            v.take_focus()
+
+        if not self.settings.get('channel_follows_focus', False):
+            self.change_channel(chname, raisew=True)
         return True
 
     def focus_cb(self, viewer, tf, name):
         """Called when ``viewer`` gets ``(tf==True)`` or loses
         ``(tf==False)`` the focus.
         """
-        if not self.channel_follows_focus:
+        if not self.settings.get('channel_follows_focus', False):
             return True
 
-        self.logger.info("Focus %s=%s" % (name, tf))
+        self.logger.debug("focus %s=%s" % (name, tf))
         if tf:
             if viewer != self.getfocus_viewer():
                 self.change_channel(name, raisew=False)
