@@ -30,7 +30,7 @@ import time
 import threading
 
 from ginga import GingaPlugin
-from ginga import RGBImage
+from ginga import RGBImage, BaseImage
 from ginga.misc import Bunch
 from ginga.util import iohelper
 from ginga.gw import Widgets, Viewers
@@ -178,6 +178,7 @@ class Thumbs(GingaPlugin.GlobalPlugin):
 
         iw = Viewers.GingaScrolledViewerWidget(c_v)
         iw.resize(self._wd, self._ht)
+        iw.scroll_bars(horizontal='auto', vertical='auto')
 
         vbox.add_widget(iw, stretch=1)
 
@@ -682,6 +683,12 @@ class Thumbs(GingaPlugin.GlobalPlugin):
     def _regen_thumb_image(self, image, viewer):
         self.logger.debug("generating new thumbnail")
 
+        if not isinstance(image, BaseImage.BaseImage):
+            # this is not a regular image type
+            image = RGBImage.RGBImage()
+            tmp_path = os.path.join(icondir, 'fits.png')
+            image.load_file(tmp_path)
+
         self.thumb_generator.set_image(image)
         if viewer is not None:
             v_img = viewer.get_image()
